@@ -144,6 +144,7 @@ class a2svm:
 		print "-"*119
 		print '| {0:20}| {1:20}| {2:8}| {3:30}| {4:30}|'.format("Name", "Macro", "Enabled", "ServerName", "Directory")
 		print "-"*119
+		vhost_list.sort(key=lambda x: x.name)
 		for vhost in vhost_list:
 			print '| {0:20}| {1:20}| {2:8}| {3:30}| {4:30}|'.format(vhost.name[:20], vhost.macro[:20], vhost.enabled[:8], vhost.servername[:30], vhost.directory[:30])
 		print "-"*119
@@ -165,15 +166,18 @@ class a2svm:
 					vhost.directory = match.group(5)
 					return vhost
 
-	def make(self, vhost):
+	def make(self, vhost, opt_args):
 		vhost_file = os.path.join(self.vhost_config_path, vhost.name)
-		vhost_content = "use "+vhost.macro+" "+vhost.name+" "+vhost.servername+" "+vhost.directory
 		macro_parameters = self.get_macro_parameter(vhost, "#a2svm_make_command:")
+		opt_args_content = ""
 		print "The vhost will be created"
 		print " -Name: "+vhost.name
 		print " -Macro: "+vhost.macro
 		print " -ServerName: "+vhost.servername
 		print " -Directory: "+vhost.directory
+		for arg in opt_args:
+			 print "  *optional argument: \""+arg+"\""
+			 opt_args_content = opt_args_content+" \""+arg+"\""
 		print "The following command will be executed"
 		print " "+'\n '.join(str(parameter) for parameter in macro_parameters)
 		confirm=query_yes_no("Are you sure?")
@@ -181,6 +185,7 @@ class a2svm:
 			sys.exit(1)
 		for parameter in macro_parameters:
 			self.run_command(parameter," ","run:" + parameter)
+		vhost_content = "use "+vhost.macro+" "+vhost.name+" "+vhost.servername+" "+vhost.directory+opt_args_content
 		if not os.path.exists(os.path.dirname(vhost_file)):
 			os.makedirs(os.path.dirname(vhost_file))
 		with open(vhost_file, 'wb') as dest_file:
@@ -225,7 +230,7 @@ class a2svm:
 
 	def get_macro_parameter(self, vhost, parameter):
 		macro_file = os.path.join(self.macro_path, vhost.macro)
-		expr = re.compile('(^'+parameter+') ([.\/\ \:\$\-\_a-zA-Z0-9_]+)')
+		expr = re.compile('(^'+parameter+') ([.\/\ \:\$\-\+\_a-zA-Z0-9_]+)')
 		subdict = dict(servername=vhost.servername ,directory=vhost.directory ,name=vhost.name , macro=vhost.macro)
 		parameters_list = []
 		with open(macro_file, 'r') as macro_content:
@@ -251,6 +256,8 @@ def launcher():
 	parser_mk.add_argument('mk_vhost_macro', metavar='<vhost_macro>', type=str, help='Macro used by the vhost')
 	parser_mk.add_argument('mk_vhost_servername', metavar='<vhost_servername>', type=str, help='ServerName of the vhost')
 	parser_mk.add_argument('mk_vhost_directory', metavar='<vhost_directory>', type=str, help='Directory of the vhost')
+	parser_mk.add_argument('mk_opt_args', metavar='[optionnal_macro_arg]', nargs='*', type=str, help='Optionnal macro argument')
+
 
 	parser_ls = subparsers.add_parser('ls', description='Show vhost on Apache server', help='Show vhost on Apache server')
 	parser_ls.add_argument('ls_vhost_pattern', metavar='<search_pattern>', type=str, nargs='?', default='%', help='Show only vhost name matching pattern')
@@ -272,7 +279,7 @@ def launcher():
 		vhost.macro = args.mk_vhost_macro
 		vhost.servername = args.mk_vhost_servername
 		vhost.directory = args.mk_vhost_directory
-		session.make(vhost)
+		session.make(vhost,args.mk_opt_args)
 
 	if hasattr(args,'ls_vhost_pattern'):
 		session.list()
